package simple.documentation.framework.operations;

import java.awt.Toolkit;
import java.awt.datatransfer.Clipboard;
import java.awt.datatransfer.StringSelection;

import javax.swing.text.BadLocationException;

import ro.sync.ecss.extensions.api.ArgumentDescriptor;
import ro.sync.ecss.extensions.api.ArgumentsMap;
import ro.sync.ecss.extensions.api.AuthorAccess;
import ro.sync.ecss.extensions.api.AuthorOperation;
import ro.sync.ecss.extensions.api.AuthorOperationException;
import ro.sync.ecss.extensions.api.node.AuthorDocumentFragment;

/**
 * Copy XML operation. 
 */
public class CopyXMLOperation implements AuthorOperation {

  /**
   * 
   * @see ro.sync.ecss.extensions.api.AuthorOperation#doOperation(ro.sync.ecss.extensions.api.AuthorAccess, ro.sync.ecss.extensions.api.ArgumentsMap)
   */
  public void doOperation(final AuthorAccess authorAccess, ArgumentsMap args) 
      throws IllegalArgumentException, AuthorOperationException { 
    
    // Get selection 
    int selectionStart = authorAccess.getSelectionStart();
    int selectionEnd = authorAccess.getSelectionEnd();
    
    try {
      if (selectionStart < selectionEnd) {
        // Create the fragment from the selection
        AuthorDocumentFragment docFragment = authorAccess.getDocumentController().createDocumentFragment(selectionStart, selectionEnd - 1);
        String serializedFragment = authorAccess.getDocumentController().serializeFragmentToXML(docFragment);
        StringSelection data = new StringSelection(serializedFragment);
        // Copy to clipboard
        Clipboard clipboard = Toolkit.getDefaultToolkit().getSystemClipboard();
        clipboard.setContents(data, data);
      }
    } catch (BadLocationException e) {
      e.printStackTrace();
    }
  } 

  /**
   * @see ro.sync.ecss.extensions.api.AuthorOperation#getArguments()
   */
  public ArgumentDescriptor[] getArguments() {
    return null;
  }

  /**
   * @see ro.sync.ecss.extensions.api.Extension#getDescription()
   */
  public String getDescription() {
    return "Copy XML";
  }

}
